@@ -1,5 +1,6 @@
 package Sidef::Deparse::Sidef {
 
+    use utf8;
     use 5.014;
     use Scalar::Util qw(refaddr reftype);
 
@@ -555,7 +556,7 @@ package Sidef::Deparse::Sidef {
             $code = $obj->{name};
         }
         elsif ($ref eq 'Sidef::Types::Hash::Hash') {
-            $code = keys(%{$obj}) ? $obj->dump->get_value : 'Hash';
+            $code = $obj->dump->get_value;
         }
         elsif ($ref eq 'Sidef::Types::Number::Number') {
             $code = $self->_dump_number($obj);
